You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:05:21 UTC

svn commit: r1591058 [11/15] - in /openoffice/trunk/main: ./ accessibility/bridge/org/openoffice/java/accessibility/ accessibility/bridge/source/java/ accessibility/inc/accessibility/extended/ accessibility/inc/accessibility/standard/ accessibility/sou...

Modified: openoffice/trunk/main/framework/inc/services/autorecovery.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/autorecovery.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/backingcomp.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/backingcomp.hxx Tue Apr 29 19:05:05 2014
@@ -78,7 +78,7 @@ class BackingComp : public  css::lang::X
                   , public  css::lang::XInitialization
                   , public  css::frame::XController  // => XComponent
                   , public  css::awt::XKeyListener // => XEventListener
-                  // attention! Must be the first base class to guarentee right initialize lock ...
+                  // attention! Must be the first base class to guarantee right initialize lock ...
                   , private ThreadHelpBase
                   , public  ::cppu::OWeakObject
 {

Modified: openoffice/trunk/main/framework/inc/services/contenthandlerfactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/contenthandlerfactory.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/contenthandlerfactory.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/contenthandlerfactory.hxx Tue Apr 29 19:05:05 2014
@@ -106,7 +106,7 @@ class ContentHandlerFactory :   // inter
 						public	css::container::XNameContainer		,		// => XNameReplace => XNameAccess => XElementAccess
 						public	css::util::XFlushable				,
 						// base classes
-						// Order is neccessary for right initialization of it!
+						// Order is necessary for right initialization of it!
                         private ThreadHelpBase                      ,
                         private TransactionBase                     ,
 						public	::cppu::OWeakObject

Modified: openoffice/trunk/main/framework/inc/services/desktop.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/desktop.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/desktop.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/desktop.hxx Tue Apr 29 19:05:05 2014
@@ -144,7 +144,7 @@ class Desktop   :   // interfaces
                     public  css::task::XInteractionHandler       ,
                     public  css::frame::XUntitledNumbers         ,
                     // base classes
-                    // Order is neccessary for right initialization!
+                    // Order is necessary for right initialization!
                     private ThreadHelpBase                       ,
                     private TransactionBase                      ,
                     public  ::cppu::OBroadcastHelper             ,
@@ -186,7 +186,7 @@ class Desktop   :   // interfaces
 
                         Btw: Desktop.terminate() was designed in the past to be used
                         within an UI based envrionment. So it's allowed e.g. to
-                        call XController.suspend() here. If UI isnt an option ... please
+                        call XController.suspend() here. If UI isn't an option ... please
                         use XCloseable.close() at these desktop implementation.
                         ... if it will be supported in the future .-))
 
@@ -411,9 +411,9 @@ class Desktop   :   // interfaces
          *
          *  Iterates over all child frames and try to close them.
          *  Given parameter bAllowUI enable/disable showing any UI
-         *  (which mostly occure on calling XController->suspend()).
+         *  (which mostly occur on calling XController->suspend()).
          *
-         *  These method doesnt stop if one frame could not be closed.
+         *  These method doesn't stop if one frame could not be closed.
          *  It will ignore such frames and try all other ones.
          *  But it returns false in such case - true otherwise.
          *
@@ -426,7 +426,7 @@ class Desktop   :   // interfaces
 
 	//-------------------------------------------------------------------------------------------------------------
 	//	debug methods
-    //  (should be private everytime!)
+    //  (should be private every time!)
 	//-------------------------------------------------------------------------------------------------------------
     #ifdef ENABLE_ASSERTIONS
     private:
@@ -442,7 +442,7 @@ class Desktop   :   // interfaces
 
 	//-------------------------------------------------------------------------------------------------------------
 	//	variables
-    //  (should be private everytime!)
+    //  (should be private every time!)
 	//-------------------------------------------------------------------------------------------------------------
 	private:
 
@@ -476,7 +476,7 @@ class Desktop   :   // interfaces
 
         //---------------------------------------------------------------------
         /** special terminate listener which loads images asynchronous for current open documents.
-          * Because internaly it uses blocking system APIs ... it cant be guaranteed that
+          * Because internaly it uses blocking system APIs ... it can't be guaranteed that
           * running jobs can be cancelled successfully if the corressponding document will be closed ...
           * it will not hinder those documents on closing. Instead it let all jobs running ...
           * but at least on terminate we have to wait for all those blocked requests.
@@ -487,15 +487,15 @@ class Desktop   :   // interfaces
         //---------------------------------------------------------------------
         /** special terminate listener shuting down the SfxApplication.
           * Because these desktop instance closes documents and informs listener
-          * only ... it does not realy shutdown the whole application.
+          * only ... it does not really shutdown the whole application.
           *
           * Btw: That wouldnt be possible by design ... because Desktop.terminate()
-          * has to return a boolean value about success ... it cant realy shutdown the
+          * has to return a boolean value about success ... it can't really shutdown the
           * process .-)
           *
           * So we uses a trick: A special listener (exactly these one here) listen for notifyTermination()
           * and shutdown the process asynchronous. But desktop has to make this special
-          * notification as realy last one ... Otherwhise it can happen that asynchronous
+          * notification as really last one ... Otherwise it can happen that asynchronous
           * shutdown will be faster then all other code around Desktop.terminate() .-))
           */
         css::uno::Reference< css::frame::XTerminateListener > m_xSfxTerminator;

Modified: openoffice/trunk/main/framework/inc/services/detectorfactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/detectorfactory.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/frame.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/frame.hxx Tue Apr 29 19:05:05 2014
@@ -94,7 +94,7 @@ namespace framework{
 //	exported const
 //_________________________________________________________________________________________________________________
 
-// This enum can be used to set differnt active states of frames
+// This enum can be used to set different active states of frames
 enum EActiveState
 {
 	E_INACTIVE		,	// I'am not a member of active path in tree and i don't have the focus.
@@ -152,7 +152,7 @@ class Frame	:	// interfaces
                 public  css::frame::XTitle                          ,
                 public  css::frame::XTitleChangeBroadcaster         ,
 				// base classes
-				// Order is neccessary for right initialization of this class!
+				// Order is necessary for right initialization of this class!
                 public  ThreadHelpBase                              ,
                 public  TransactionBase                             ,
                 public  PropertySetHelper                           ,   // helper implements ThreadHelpbase, TransactionBase, XPropertySet, XPropertySetInfo

Modified: openoffice/trunk/main/framework/inc/services/frameloaderfactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/frameloaderfactory.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/frameloaderfactory.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/frameloaderfactory.hxx Tue Apr 29 19:05:05 2014
@@ -248,14 +248,14 @@ class FrameLoaderFactory	:	public Thread
 			@param		-
 			@return		A list of well known loader. Is static at runtime!
 
-			@onerror	No error should occure.
+			@onerror	No error should occur.
 		*//*-*****************************************************************************************************/
 
     	virtual css::uno::Sequence< ::rtl::OUString > SAL_CALL getElementNames() throw( css::uno::RuntimeException );
 
 		/*-****************************************************************************************************//**
 			@short		check if searched frame loader exist in configuration
-			@descr		Normaly nobody need these method realy (use getElementNames() in combination with getByName()).
+			@descr		Normaly nobody needs really these method (use getElementNames() in combination with getByName()).
 						We guarantee correctness of these mechanism. There is no reason to check for existing elements then ...
 						but if you have an unknwon name and has no fun to search it in returned sequence ...
 						you can call these ...
@@ -266,7 +266,7 @@ class FrameLoaderFactory	:	public Thread
 			@param		"sName", implementation name of searched frame loader
 			@return		sal_True if loader exist, sal_False otherwise.
 
-			@onerror	No error should occure.
+			@onerror	No error should occur.
 		*//*-*****************************************************************************************************/
 
     	virtual sal_Bool SAL_CALL hasByName( const ::rtl::OUString& sName ) throw( css::uno::RuntimeException );
@@ -277,14 +277,14 @@ class FrameLoaderFactory	:	public Thread
 
 		/*-****************************************************************************************************//**
 			@short		return the type of retrun value of method XNameAccess::getByName()
-			@descr		In these implementation its a Sequence< PropertyValue > everytime!
+			@descr		In these implementation its a Sequence< PropertyValue > every time!
 
 			@seealso	description of interface XNameAccess
 
 			@param		-
 			@return		Type of Sequence< PropertyValue >.
 
-			@onerror	No error should occure.
+			@onerror	No error should occur.
 		*//*-*****************************************************************************************************/
 
 		virtual css::uno::Type SAL_CALL getElementType() throw( css::uno::RuntimeException );
@@ -299,7 +299,7 @@ class FrameLoaderFactory	:	public Thread
 			@param		-
 			@return		sal_True if information available, sal_False otherwise.
 
-			@onerror	No error should occure.
+			@onerror	No error should occur.
 		*//*-*****************************************************************************************************/
 
     	virtual sal_Bool SAL_CALL hasElements() throw( css::uno::RuntimeException );
@@ -329,7 +329,7 @@ class FrameLoaderFactory	:	public Thread
 			@param		"pLoaderInfo" configuration structure of these loader.
 			@return		-
 
-			@onerror	No error should occure.
+			@onerror	No error should occur.
 		*//*-*****************************************************************************************************/
 
 		void impl_initializeLoader( css::uno::Reference< css::uno::XInterface >& xLoader, const Loader& pLoaderInfo );

Modified: openoffice/trunk/main/framework/inc/services/layoutmanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/layoutmanager.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/layoutmanager.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/layoutmanager.hxx Tue Apr 29 19:05:05 2014
@@ -101,7 +101,7 @@ namespace framework
     typedef ::comphelper::OPropertyContainer    LayoutManager_PBase;
     class LayoutManager : public  LayoutManager_Base                    ,
                           // base classes
-                          // Order is neccessary for right initialization!
+                          // Order is necessary for right initialization!
                           private ThreadHelpBase						,	// Struct for right initalization of mutex member! Must be first of baseclasses.
                           public  ::cppu::OBroadcastHelper              ,
                           public  ILayoutNotifications                  ,

Modified: openoffice/trunk/main/framework/inc/services/license.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/license.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/license.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/license.hxx Tue Apr 29 19:05:05 2014
@@ -68,7 +68,7 @@ namespace framework
                     public  css::task::XJob                     ,
                     public  css::util::XCloseable               ,
                     // base classes
-                    // Order is neccessary for right initialization!
+                    // Order is necessary for right initialization!
                     private ThreadHelpBase						, // Struct for right initalization of mutex member! Must be first of baseclasses.
                     public  ::cppu::OWeakObject                   // => XWeak, XInterface
     {

Modified: openoffice/trunk/main/framework/inc/services/logindialog.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/logindialog.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/modulemanager.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/modulemanager.hxx Tue Apr 29 19:05:05 2014
@@ -64,7 +64,7 @@ class ModuleManager : public  css::lang:
                     , public  css::frame::XModuleManager
                     , public  css::container::XNameReplace // => XNameAccess, XElementAccess
                     , public  css::container::XContainerQuery
-                    // attention! Must be the first base class to guarentee right initialize lock ...
+                    // attention! Must be the first base class to guarantee right initialize lock ...
                     , private ThreadHelpBase
                     , public  ::cppu::OWeakObject
 {
@@ -154,7 +154,7 @@ class ModuleManager : public  css::lang:
     
                     Note: A writable configuration access
                     must be created explicitly. Otherwise
-                    we cant make sure that broken write requests
+                    we can't make sure that broken write requests
                     wont affect our read access !
 
             @return [com.sun.star.container.XNameAccess]

Modified: openoffice/trunk/main/framework/inc/services/pathsettings.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/pathsettings.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/substitutepathvars.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/substitutepathvars.hxx Tue Apr 29 19:05:05 2014
@@ -188,7 +188,7 @@ enum PreDefVariable
     PREDEFVAR_PROGURL,
     PREDEFVAR_USERURL,
     PREDEFVAR_WORKDIRURL,
-    // --> PB 2004-10-27 #i32656# - new variable of hierachy service
+    // --> PB 2004-10-27 #i32656# - new variable of hierarchy service
     PREDEFVAR_BASEINSTURL,
     PREDEFVAR_USERDATAURL,
     // <--

Modified: openoffice/trunk/main/framework/inc/services/task.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/task.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/task.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/task.hxx Tue Apr 29 19:05:05 2014
@@ -77,7 +77,7 @@ namespace framework{
 *//*-*************************************************************************************************************/
 
 class Task  :   public css::frame::XTask    ,   // => XFrame => XComponent
-                public Frame                    // Order of baseclasses is neccessary for right initialization!
+                public Frame                    // Order of baseclasses is necessary for right initialization!
 {
 	//-------------------------------------------------------------------------------------------------------------
 	//	public methods
@@ -429,7 +429,7 @@ class Task  :   public css::frame::XTask
 						Don't use this directly!
 						You must try to convert the value of given propertyhandle and
 						return results of this operation. This will be use to ask vetoable
-						listener. If no listener have a veto, we will change value realy!
+						listener. If no listener have a veto, we will change value really!
 						( in method setFastPropertyValue_NoBroadcast(...) )
 
 			@seealso	OPropertySetHelper
@@ -455,7 +455,7 @@ class Task  :   public css::frame::XTask
 			@descr		This method is calling from helperclass "OPropertySetHelper".
 						Don't use this directly!
 						Handle and value are valid everyway! You must set the new value only.
-						After this, baseclass send messages to all listener automaticly.
+						After this, baseclass send messages to all listener automatically.
 
 			@seealso	OPropertySetHelper
 

Modified: openoffice/trunk/main/framework/inc/services/taskcreatorsrv.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/taskcreatorsrv.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/taskcreatorsrv.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/taskcreatorsrv.hxx Tue Apr 29 19:05:05 2014
@@ -62,7 +62,7 @@ namespace framework
 class TaskCreatorService : public  css::lang::XTypeProvider
                          , public  css::lang::XServiceInfo
                          , public  css::lang::XSingleServiceFactory
-                           // attention! Must be the first base class to guarentee right initialize lock ...
+                           // attention! Must be the first base class to guarantee right initialize lock ...
                          , private ThreadHelpBase
                          , public  ::cppu::OWeakObject
 {
@@ -99,7 +99,7 @@ class TaskCreatorService : public  css::
         static const ::rtl::OUString ARGUMENT_SUPPORTPERSISTENTWINDOWSTATE;
 
         /** [sal_Bool] enable/disable special mode, where the title bar of our 
-                       the new created frame will be updated automaticly.
+                       the new created frame will be updated automatically.
                        Default = ON !
          */
         static const ::rtl::OUString ARGUMENT_ENABLE_TITLEBARUPDATE;

Modified: openoffice/trunk/main/framework/inc/stdtypes.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/stdtypes.h?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/stdtypes.h (original)
+++ openoffice/trunk/main/framework/inc/stdtypes.h Tue Apr 29 19:05:05 2014
@@ -104,7 +104,7 @@ struct KeyEventEqualsFunc
 
 /**
     Basic string list based on a std::vector()
-    It implements some additional funtionality which can be usefull but
+    It implements some additional funtionality which can be useful but
     is missing at the normal vector implementation.
 */
 class OUStringList : public ::comphelper::SequenceAsVector< ::rtl::OUString >
@@ -128,7 +128,7 @@ class OUStringList : public ::comphelper
             return ::std::find(begin(), end(), sElement);
         }
 
-        // the only way to free used memory realy!
+        // the only way to free used memory really!
         void free()
 		{
             OUStringList().swap( *this );
@@ -139,7 +139,7 @@ class OUStringList : public ::comphelper
 
 /**
     Basic string queue based on a std::queue()
-    It implements some additional funtionality which can be usefull but
+    It implements some additional funtionality which can be useful but
     is missing at the normal std implementation.
 */
 typedef ::std::queue< ::rtl::OUString > OUStringQueue;
@@ -148,7 +148,7 @@ typedef ::std::queue< ::rtl::OUString > 
 
 /**
     Basic hash based on a std::hash_map() which provides key=[OUString] and value=[template type] pairs
-    It implements some additional funtionality which can be usefull but
+    It implements some additional funtionality which can be useful but
     is missing at the normal hash implementation.
 */
 template< class TType >
@@ -159,7 +159,7 @@ class BaseHash : public ::std::hash_map<
 {
 	public:
 
-        // the only way to free used memory realy!
+        // the only way to free used memory really!
 		void free()
 		{
             BaseHash().swap( *this );

Modified: openoffice/trunk/main/framework/inc/threadhelp/fairrwlock.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/fairrwlock.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/fairrwlock.hxx (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/fairrwlock.hxx Tue Apr 29 19:05:05 2014
@@ -85,7 +85,7 @@ class FairRWLock : public  IRWLock
             @short      standard ctor
             @descr      Initialize instance with right start values for correct working.
                         no reader could exist               =>  m_nReadCount   = 0
-                        don't block first comming writer    =>  m_aWriteCondition.set()
+                        don't block first coming writer    =>  m_aWriteCondition.set()
 
             @seealso    -
 
@@ -231,7 +231,7 @@ class FairRWLock : public  IRWLock
 
             @attention  Don't call this method if you are not a writer!
                         Results are not defined then ...
-                        An upgrade can't be implemented realy ... because acquiring new access
+                        An upgrade can't be really implemented ... because acquiring new access
                         will be the same - there no differences!
 
             @seealso    -

Modified: openoffice/trunk/main/framework/inc/threadhelp/gate.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/gate.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/gate.hxx (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/gate.hxx Tue Apr 29 19:05:05 2014
@@ -165,7 +165,7 @@ class Gate : public  IGate
 			@short		open gate for current waiting threads
 			@descr		All current waiting threads stand in wait() at line "m_aPassage.wait()" ...
 						With this call you can open the passage for these waiting ones.
-						The "gap" is closed by any new thread which call wait() automaticly!
+						The "gap" is closed by any new thread which call wait() automatically!
 
 			@seealso	method wait()
 			@seealso	method open()

Modified: openoffice/trunk/main/framework/inc/threadhelp/inoncopyable.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/inoncopyable.h?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/inoncopyable.h (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/inoncopyable.h Tue Apr 29 19:05:05 2014
@@ -52,8 +52,8 @@ namespace framework{
 
 /*-************************************************************************************************************//**
 	@descr			Use this as one of your base classes to disable
-					all possiblities to copy or assign one object to another one!
-					We declare neccessary functions private to do so.
+					all possibilities to copy or assign one object to another one!
+					We declare necessary functions private to do so.
 *//*-*************************************************************************************************************/
 class INonCopyable
 {

Modified: openoffice/trunk/main/framework/inc/threadhelp/itransactionmanager.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/itransactionmanager.h?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/itransactionmanager.h (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/itransactionmanager.h Tue Apr 29 19:05:05 2014
@@ -44,7 +44,7 @@ namespace framework{
 
 /*-************************************************************************************************************//**
 	@descr			Describe different states of a feature of following implementation.
-					During live time of an object different working states occure:
+					During live time of an object different working states occur:
 						initialization - working - closing - closed
 					If you whish to implement thread safe classes you should use these feature to protect
 					your code against calls at wrong time. e.g. you are not full initialized but somewhere
@@ -113,7 +113,7 @@ enum EExceptionMode
 /*-************************************************************************************************************//**
     @descr          How can you use the transaction manager?
                     Use it in combination with an TransactionGuard, which register your transaction in ctor
-                    and release in dtor automaticly! Follow interface class can be used to make using
+                    and release in dtor automatically! Follow interface class can be used to make using
                     of different manager implmentations possible by using same guard.
 *//*-*************************************************************************************************************/
 class ITransactionManager

Modified: openoffice/trunk/main/framework/inc/threadhelp/lockhelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/lockhelper.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/lockhelper.hxx (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/lockhelper.hxx Tue Apr 29 19:05:05 2014
@@ -79,12 +79,12 @@ enum ELockType
     @short          helper to set right lock in right situation
     @descr          This helper support different types of locking:
                         a)  no locks - transparent for user!
-                            This could be usefull for simluation or single threaded environments!
+                            This could be useful for simluation or single threaded environments!
                         b)  own mutex
-                            An object use his own osl-mutex to be threadsafe. Usefull for easy and exclusiv locking.
+                            An object use his own osl-mutex to be threadsafe. Useful for easy and exclusiv locking.
                         c)  solar mutex
                             An object use our solar mutex and will be a part of a greater safed "threadsafe code block".
-                            Could be usefull for simulation and testing of higher modules!
+                            Could be useful for simulation and testing of higher modules!
                         d)  fair rw-lock
                             An object use an implementation of a fair rw-lock. This increase granularity of t hreadsafe mechanism
                             and should be used for high performance threadsafe code!
@@ -153,10 +153,10 @@ class FWI_DLLPUBLIC LockHelper : public 
     //     ... or the solarmuex as "m_pSolarMutex" (must be set from outside! because some components must be vcl-free!)
     //     ... but sometimes you need a shareable osl mutex!
     //     In this case you has some problems: i  ) If your lock type is set to E_OWNMUTEX => it's easy; you can use your member "m_pOwnMutex" - it's a osl mutex.
-    //                                              Creation and using of "m_pShareableOslMutex" isn't neccessary!
+    //                                              Creation and use of "m_pShareableOslMutex" isn't necessary!
     //                                         ii ) Otherwise you have no osl mutex ... so you must create "m_pShareableOslMutex" and use it twice!
-    //                                              In this case you must lock two member everytime - "m_pShareableMutex" AND "m_pFairRWLock" or "m_pSolarMutex" or ...
-    //                                              It isn't realy fine - but the only possible way.
+    //                                              In this case you must lock two members every time - "m_pShareableMutex" AND "m_pFairRWLock" or "m_pSolarMutex" or ...
+    //                                              It isn't really fine - but the only possible way.
     //                                         iii) There exist another special case - E_NOTHING is set! Then we should create this shareable mutex ...
     //                                              nad you can use it ... but this implmentation ignore it.
     //-------------------------------------------------------------------------------------------------------------

Modified: openoffice/trunk/main/framework/inc/threadhelp/readguard.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/readguard.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/readguard.hxx (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/readguard.hxx Tue Apr 29 19:05:05 2014
@@ -63,7 +63,7 @@ namespace framework{
 	@descr			This guard should be used to set a lock for reading object internal member.
 					Nobody can control it but don't use member after successfuly locking for writing!
 					We never need a own mutex to safe our internal member access - because
-					a guard is used as function-local member only. There exist no multithreaded access to it realy ...
+					a guard is used as function-local member only. There exists no multithreaded access to it really ...
 
     @attention      a) To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
                     b) Use interface "IRWLock" of set LockHelper only - because we must support a finer granularity of locking.
@@ -111,7 +111,7 @@ class ReadGuard : private INonCopyable
 
         /*-****************************************************************************************************//**
             @short      dtor
-            @descr      We unlock the used lock member automaticly if user forget it.
+            @descr      We unlock the used lock member automatically if user forgets it.
 
             @seealso    -
 
@@ -148,7 +148,7 @@ class ReadGuard : private INonCopyable
         /*-****************************************************************************************************//**
             @short      unset read lock
             @descr      Call this method to unlock the rw-lock temp.!
-                        Normaly we do it at dtor automaticly for you ...
+                        Normaly we do it at dtor automatically for you ...
 
             @seealso    method lock()
 
@@ -173,7 +173,7 @@ class ReadGuard : private INonCopyable
 
 		/*-****************************************************************************************************//**
 			@short		disable using of these functions!
-			@descr		It's not allowed to use this methods. Different problem can occure otherwise.
+			@descr		It's not allowed to use this methods. Different problems can occur otherwise.
 						Thats why we disable it by make it private.
 
 			@seealso	other ctor

Modified: openoffice/trunk/main/framework/inc/threadhelp/resetableguard.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/resetableguard.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/resetableguard.hxx (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/resetableguard.hxx Tue Apr 29 19:05:05 2014
@@ -84,7 +84,7 @@ class ResetableGuard : private INonCopya
 		/*-****************************************************************************************************//**
 			@short		ctors
 			@descr		Use these ctor methods to initialize the guard right.
-                        Given lock reference must be valid - otherwise crashes could occure!
+                        Given lock reference must be valid - otherwise crashes could occur!
 
 			@seealso	-
 
@@ -169,7 +169,7 @@ class ResetableGuard : private INonCopya
 
 		/*-****************************************************************************************************//**
 			@short		disable using of these functions!
-			@descr		It's not allowed to use this methods. Different problem can occure otherwise.
+			@descr		It's not allowed to use this methods. Different problems can occur otherwise.
 						Thats why we disable it by make it private.
 
 			@seealso	other ctor

Modified: openoffice/trunk/main/framework/inc/threadhelp/transactionguard.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/transactionguard.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/transactionguard.hxx (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/transactionguard.hxx Tue Apr 29 19:05:05 2014
@@ -58,9 +58,9 @@ namespace framework{
     @descr          If you whish to support non breakable method calls without lockingf any mutex, rw-lock or
                     something like that - you should use this guard implementation.
                     Initialize it at first in your method and don't release it till end of your function!
-                    Your "transaction" is registered in ctor and automaticly released in dtor.
+                    Your "transaction" is registered in ctor and automatically released in dtor.
                     Use set/get of working mode to enable/disable further transactions.
-                    It's possible too, to enable automaticly throwing of some exceptions for illegal
+                    It's possible too, to enable automatically throwing of some exceptions for illegal
                     transaction requests ... e.g. interface call for already disposed objects.
 
 	@attention		To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
@@ -80,9 +80,9 @@ class TransactionGuard : private INonCop
         /*-****************************************************************************************************//**
             @short      ctors
             @descr      Use these ctor methods to initialize the guard right.
-                        Given reference must be valid - otherwise crashes could occure!
+                        Given reference must be valid - otherwise crashes could occur!
 
-            @attention  It's not neccessary to lock any mutex here! Because a ctor should not be called
+            @attention  It's not necessary to lock any mutex here! Because a ctor should not be called
                         from different threads at the same time ... this class use no refcount mechanism!
 
             @seealso    -
@@ -158,7 +158,7 @@ class TransactionGuard : private INonCop
 
 		/*-****************************************************************************************************//**
 			@short		disable using of these functions!
-			@descr		It's not allowed to use this methods. Different problem can occure otherwise.
+			@descr		It's not allowed to use this methods. Different problems can occur otherwise.
 						Thats why we disable it by make it private.
 
 			@seealso	other ctor

Modified: openoffice/trunk/main/framework/inc/threadhelp/transactionmanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/transactionmanager.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/transactionmanager.hxx (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/transactionmanager.hxx Tue Apr 29 19:05:05 2014
@@ -67,7 +67,7 @@ namespace framework{
                     synchronization like e.g. mutex, rw-lock!
                     That protect your code against wrong calls at wrong time ... e.g. calls after disposing an object!
                     Use combination of EExceptionMode and ERejectReason to detect rejected requests
-                    and react for it. You can enable automaticly throwing of exceptions too.
+                    and react for it. You can enable automatically throwing of exceptions too.
 
     @implements     ITransactionManager
     @base           INonCopyable

Modified: openoffice/trunk/main/framework/inc/threadhelp/writeguard.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/threadhelp/writeguard.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/uifactory/uielementfactorymanager.hxx (original)
+++ openoffice/trunk/main/framework/inc/uifactory/uielementfactorymanager.hxx Tue Apr 29 19:05:05 2014
@@ -62,7 +62,7 @@ namespace framework
 
     class ConfigurationAccess_FactoryManager : // interfaces
                                                     // baseclasses
-							                        // Order is neccessary for right initialization!
+							                        // Order is necessary for right initialization!
                                                     private ThreadHelpBase                           ,
                                                     public  ::cppu::WeakImplHelper1< ::com::sun::star::container::XContainerListener>
 {

Modified: openoffice/trunk/main/framework/inc/xml/acceleratorconfigurationreader.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/xml/acceleratorconfigurationreader.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/xml/acceleratorconfigurationreader.hxx (original)
+++ openoffice/trunk/main/framework/inc/xml/acceleratorconfigurationreader.hxx Tue Apr 29 19:05:05 2014
@@ -126,7 +126,7 @@ class AcceleratorConfigurationReader : p
         /** @short  provide informations abou the parsing state.
         
             @descr  We use it to find out the line and column, where
-                    an error occure.
+                    an error occur.
           */
 		css::uno::Reference< css::xml::sax::XLocator > m_xLocator;
         

Modified: openoffice/trunk/main/framework/qa/complex/XUserInputInterception/EventTest.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/XUserInputInterception/EventTest.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/XUserInputInterception/EventTest.java (original)
+++ openoffice/trunk/main/framework/qa/complex/XUserInputInterception/EventTest.java Tue Apr 29 19:05:05 2014
@@ -415,7 +415,7 @@ public class EventTest {
             return true;
         }
         /**
-         * This event does nothing usefull
+         * This event does nothing useful
          * @param oEvent refers to the object that fired the event.
          */
         public void disposing( EventObject oEvent ){
@@ -451,7 +451,7 @@ public class EventTest {
             return true;
         }
         /**
-         * This event does nothing usefull
+         * This event does nothing useful
          * @param oEvent refers to the object that fired the event.
          */
         public void disposing( EventObject oEvent ){

Modified: openoffice/trunk/main/framework/qa/complex/contextMenuInterceptor/ContextMenuInterceptor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/contextMenuInterceptor/ContextMenuInterceptor.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/contextMenuInterceptor/ContextMenuInterceptor.java (original)
+++ openoffice/trunk/main/framework/qa/complex/contextMenuInterceptor/ContextMenuInterceptor.java Tue Apr 29 19:05:05 2014
@@ -123,7 +123,7 @@ public class ContextMenuInterceptor impl
         }
         catch (com.sun.star.uno.Exception ex)
         {
-            // something strange has happend!
+            // something strange has happened!
         }
         catch (java.lang.Throwable ex)
         {

Modified: openoffice/trunk/main/framework/qa/complex/dispatches/Interceptor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/dispatches/Interceptor.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/dispatches/Interceptor.java (original)
+++ openoffice/trunk/main/framework/qa/complex/dispatches/Interceptor.java Tue Apr 29 19:05:05 2014
@@ -90,7 +90,7 @@ public class Interceptor implements XDis
 
     /** counts calls of setSlave...().
         So the outside API test can use this value to know if this interceptor
-        was realy added to the interceptor chain of OOo.
+        was really added to the interceptor chain of OOo.
      */
     private int m_nRegistrationCount = 0;
 
@@ -260,7 +260,7 @@ public class Interceptor implements XDis
     // ____________________
 
     /** set a new list of URL's, which should be used on registration time
-        (that's why it's neccessary to call this impl-method before the interceptor
+        (that's why it's necessary to call this impl-method before the interceptor
         is used at the OOo API!) to optimize the interception chain.
      */
     public synchronized void setURLs4InterceptionInfo(String[] lURLs)
@@ -271,7 +271,7 @@ public class Interceptor implements XDis
     // ____________________
 
     /** set a new list of URL's, which should be blocked by this interceptor.
-        (that's why it's neccessary to call this impl-method before the interceptor
+        (that's why it's necessary to call this impl-method before the interceptor
         is used at the OOo API!)
      */
     public synchronized void setURLs4URLs4Blocking(String[] lURLs)

Modified: openoffice/trunk/main/framework/qa/complex/dispatches/checkdispatchapi.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/dispatches/checkdispatchapi.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/dispatches/checkdispatchapi.java (original)
+++ openoffice/trunk/main/framework/qa/complex/dispatches/checkdispatchapi.java Tue Apr 29 19:05:05 2014
@@ -125,7 +125,7 @@ public class checkdispatchapi
         }
         catch (java.lang.Throwable ex)
         {
-            fail("Cant initialize test environment.");
+            fail("Can't initialize test environment.");
         }
     }
 
@@ -258,7 +258,7 @@ public class checkdispatchapi
     public void checkInterceptorLifeTime()
     {
         // Note: It's important for the following test, that aInterceptor will be hold alive by the uno reference
-        // xInterceptor. Otherwhise we cant check some internal states of aInterceptor at the end of this method, because
+        // xInterceptor. Otherwise we can't check some internal states of aInterceptor at the end of this method, because
         // it was already killed .-)
 
         Interceptor aInterceptor = new Interceptor();
@@ -283,7 +283,7 @@ public class checkdispatchapi
 
         if (bIsRegistered)
         {
-            fail("Interceptor was not deregistered automaticly on closing the corresponding frame.");
+            fail("Interceptor was not deregistered automatically on closing the corresponding frame.");
         }
 
         System.out.println("Destruction of interception chain works as designed .-)");

Modified: openoffice/trunk/main/framework/qa/complex/framework/autosave/AutoSave.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/framework/autosave/AutoSave.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/framework/autosave/AutoSave.java (original)
+++ openoffice/trunk/main/framework/qa/complex/framework/autosave/AutoSave.java Tue Apr 29 19:05:05 2014
@@ -317,7 +317,7 @@ public class AutoSave 
         {
             m_aLog.log(Protocol.TYPE_WARNING     , "got IOException on calling doc.store()."                                                            );
             m_aLog.log(Protocol.TYPE_WARNING_INFO, "Please check the reason for that more in detail."                                                   );
-            m_aLog.log(Protocol.TYPE_WARNING_INFO, "A message like \"Concurrent save requests are not allowed.\" was intended and doesnt show an error!");
+            m_aLog.log(Protocol.TYPE_WARNING_INFO, "A message like \"Concurrent save requests are not allowed.\" was intended and doesn't show an error!");
             m_aLog.log(Protocol.TYPE_WARNING_INFO, "Message of the original exception:"                                                                 );
             m_aLog.log(Protocol.TYPE_WARNING_INFO, exIO.getMessage());
         }
@@ -351,14 +351,14 @@ public class AutoSave 
                     }
                     else
                     {
-                        m_aLog.log(Protocol.TYPE_ERROR, "closeDoc() = ERROR. Doc doesnt provide needed interface!");
+                        m_aLog.log(Protocol.TYPE_ERROR, "closeDoc() = ERROR. Doc doesn't provide needed interface!");
                     }
                 }
                 catch(com.sun.star.util.CloseVetoException exVeto)
                 {
                     m_aLog.log(Protocol.TYPE_WARNING     , "got CloseVetoException on calling doc.close()."                                    );
                     m_aLog.log(Protocol.TYPE_WARNING_INFO, "Please check the reason for that more in detail."                                  );
-                    m_aLog.log(Protocol.TYPE_WARNING_INFO, "A message like \"Cant close while saving.\" was intended and doesnt show an error!");
+                    m_aLog.log(Protocol.TYPE_WARNING_INFO, "A message like \"Can't close while saving.\" was intended and doesn't show an error!");
                     m_aLog.log(Protocol.TYPE_WARNING_INFO, exVeto.getMessage());
                 }
 

Modified: openoffice/trunk/main/framework/qa/complex/framework/autosave/Protocol.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/framework/autosave/Protocol.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/framework/autosave/Protocol.java (original)
+++ openoffice/trunk/main/framework/qa/complex/framework/autosave/Protocol.java Tue Apr 29 19:05:05 2014
@@ -59,10 +59,10 @@ import java.sql.*;
 /**
  * Implements a log mechanism to create a protocol of all steps of e.g. an api test
  * It provides the possibility to write the logged meesages to a file and/or
- * to stdout/stderr (if neccessary at the same time!).
+ * to stdout/stderr (if necessary at the same time!).
  *
  *  TODO
- *      - implement filter, which e.g. supress showing of INFO data
+ *      - implement filter, which e.g. suppress showing of INFO data
  */
 public class Protocol extends JComponent
 {
@@ -195,7 +195,7 @@ public class Protocol extends JComponent
         private int m_nType;
         /// of course, we have to know the logged message too :-)
         private String m_sMessage;
-        /// and it can be usefull to know the current time, when this line was created
+        /// and it can be useful to know the current time, when this line was created
         private Timestamp m_aStamp;
 
         /** ctor for fast initializing of such line */
@@ -502,7 +502,7 @@ public class Protocol extends JComponent
 
     // ____________________
     /**
-     * For some modes it's neccessary, that we write some additional
+     * For some modes it's necessary, that we write some additional
      * informations to the log. E.g. for html we must generate close targets.
      */
     public synchronized void finish()
@@ -524,7 +524,7 @@ public class Protocol extends JComponent
     /**
      * log an unspecified message.
      *
-     * Sometimes it's not neccessary to set a special type for an message.
+     * Sometimes it's not necessary to set a special type for an message.
      * The pure message seams to be enough. The type of such "pure messages"
      * will be set to INFO.
      *
@@ -635,7 +635,7 @@ public class Protocol extends JComponent
 
         ++m_nLine;
 
-        // it's neccessary to open scopes before creatig the protocol line
+        // it's necessary to open scopes before creatig the protocol line
         // to guarantee right tab handling for new scope value!
         if ((nType & TYPE_SCOPE_OPEN) == TYPE_SCOPE_OPEN)
             ++m_nScope;
@@ -645,7 +645,7 @@ public class Protocol extends JComponent
         String       sAsciiLog = aLine.toString();
         String       sHTMLLog  = aLine.toHTML();
 
-        // it's neccessary to close scope after creatig the protocol line
+        // it's necessary to close scope after creatig the protocol line
         // to guarantee right tab handling for old scope value!
         if (
             ( m_nScope                  >  0               ) &&
@@ -671,7 +671,7 @@ public class Protocol extends JComponent
             System.err.print(sAsciiLog);
         // no else - it's a bit field of possible reactions!
         // But these both conditions must be handled together.
-        // Because we cant generate different types of log contents to the same log file.
+        // Because we can't generate different types of log contents to the same log file.
         // We preferr HTML if both types are set.
         if (
             ((m_nMode & MODE_HTML ) == MODE_HTML ) ||
@@ -757,7 +757,7 @@ public class Protocol extends JComponent
      * returns a generic html header for generating html log files
      *
      * It's used from the method finish() to generate a valid html formated file.
-     * For that its neccessary to open some special html targets like e.g. <html>.
+     * For that its necessary to open some special html targets like e.g. <html>.
      *
      * @return  A string, which includes the whole header.
      *

Modified: openoffice/trunk/main/framework/qa/complex/framework/recovery/RecoveryTest.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/framework/recovery/RecoveryTest.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/framework/recovery/RecoveryTest.java (original)
+++ openoffice/trunk/main/framework/qa/complex/framework/recovery/RecoveryTest.java Tue Apr 29 19:05:05 2014
@@ -584,7 +584,7 @@ public class RecoveryTest extends Comple
                 }
                 String tempURL = utils.getOfficeTempDir(xMSF);
                 
-                log.println("the destination for saveing is: " + tempURL);
+                log.println("the destination for saving is: " + tempURL);
                 try{
                     oUITools.setTextEditFiledText("Save to", tempURL);
                 } catch (java.lang.Exception e){
@@ -603,7 +603,7 @@ public class RecoveryTest extends Comple
     
     /**
      * This function gets the current screen size and calculate the first
-     * quarter of it. This qaurter was used to postion to Office windows.
+     * quarter of it. This qaurter was used to position to Office windows.
      * Further this function calculates the maximum window size so the window
      * is visible if it placed on extreme position.
      */
@@ -725,7 +725,7 @@ public class RecoveryTest extends Comple
         try{
             xMathDoc = SOF.createMathDoc(frameName);
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured while creating math document '"+frameName+"':");
+            log.println("Exception occurred while creating math document '"+frameName+"':");
             failed("Couldn't create test environment");
         }
         return xMathDoc;
@@ -739,16 +739,16 @@ public class RecoveryTest extends Comple
         try {
             xPS.setPropertyValue("Formula", expFormula);
         } catch(com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured while filling math document with content.");
+            log.println("Exception occurred while filling math document with content.");
             failed("Couldn't create test environment");
         } catch(com.sun.star.lang.IllegalArgumentException e) {
-            log.println("Exception occured while filling math document with content.");
+            log.println("Exception occurred while filling math document with content.");
             failed("Couldn't create test environment");
         } catch(com.sun.star.beans.PropertyVetoException e) {
-            log.println("Exception occured while filling math document with content.");
+            log.println("Exception occurred while filling math document with content.");
             failed("Couldn't create test environment");
         } catch(com.sun.star.beans.UnknownPropertyException e) {
-            log.println("Exception occured while filling math document with content.");
+            log.println("Exception occurred while filling math document with content.");
             failed("Couldn't create test environment");
         }
     }
@@ -758,7 +758,7 @@ public class RecoveryTest extends Comple
         try{
             xImpressDoc = SOF.createImpressDoc(frameName);
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured while creating impress document '"+frameName+"':");
+            log.println("Exception occurred while creating impress document '"+frameName+"':");
             failed("Couldn't create test environment");
         }
         return xImpressDoc;
@@ -809,7 +809,7 @@ public class RecoveryTest extends Comple
         try{
             xDrawDoc = SOF.createDrawDoc(frameName);
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured while creating draw document '"+frameName+"':");
+            log.println("Exception occurred while creating draw document '"+frameName+"':");
             failed("Couldn't create test environment");
         }
         return xDrawDoc;
@@ -861,16 +861,16 @@ public class RecoveryTest extends Comple
                 new Type(XStyle.class),oShapeProps.getPropertyValue("Style"));
             oShapeProps.setPropertyValue("ZOrder", new Integer(1));
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured while setting or getting property value while filling draw document with content.");
+            log.println("Exception occurred while setting or getting property value while filling draw document with content.");
             failed("Couldn't create test environment");
         } catch (com.sun.star.beans.UnknownPropertyException e) {
-            log.println("Exception occured while setting or getting property value while filling draw document with content.");
+            log.println("Exception occurred while setting or getting property value while filling draw document with content.");
             failed("Couldn't create test environment");
         } catch (com.sun.star.lang.IllegalArgumentException e) {
-            log.println("Exception occured while setting or getting property value while filling draw document with content.");
+            log.println("Exception occurred while setting or getting property value while filling draw document with content.");
             failed("Couldn't create test environment");
         } catch (com.sun.star.beans.PropertyVetoException e) {
-            log.println("Exception occured while setting or getting property value while filling draw document with content.");
+            log.println("Exception occurred while setting or getting property value while filling draw document with content.");
             failed("Couldn't create test environment");
         }
     }
@@ -888,7 +888,7 @@ public class RecoveryTest extends Comple
         try {
             xTextDoc = SOF.createTextDoc(frameName);
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured while creating text document '"+frameName+"':");
+            log.println("Exception occurred while creating text document '"+frameName+"':");
             failed("Couldn't create test environment");
         }
         return xTextDoc;
@@ -915,10 +915,10 @@ public class RecoveryTest extends Comple
                 oCursor, ControlCharacter.LINE_BREAK, false );
             }
         } catch ( com.sun.star.lang.IllegalArgumentException e ){
-            log.println("Exception occured while filling text document with content.");
+            log.println("Exception occurred while filling text document with content.");
             failed("Couldn't create test environment");
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured while filling text document with content.");
+            log.println("Exception occurred while filling text document with content.");
             failed("Couldn't create test environment");
         }
     }
@@ -930,7 +930,7 @@ public class RecoveryTest extends Comple
         try {
             xSheetDoc = SOF.createCalcDoc(frameName);
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured while creating calc document '"+frameName+"':");
+            log.println("Exception occurred while creating calc document '"+frameName+"':");
             failed("Couldn't create test environment");
         }
         return xSheetDoc;
@@ -956,19 +956,19 @@ public class RecoveryTest extends Comple
             oSheet.getCellByPosition(3, 2).setFormula("xTextDoc");
             oSheet.getCellByPosition(3, 3).setFormula("xTextDoc");
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured while filling calc document with content.");
+            log.println("Exception occurred while filling calc document with content.");
             failed("Couldn't create test environment");
         } catch (com.sun.star.container.NoSuchElementException e) {
-            log.println("Exception occured while filling calc document with content.");
+            log.println("Exception occurred while filling calc document with content.");
             failed("Couldn't create test environment");
         } catch (com.sun.star.lang.IndexOutOfBoundsException e) {
-            log.println("Exception occured while filling calc document with content.");
+            log.println("Exception occurred while filling calc document with content.");
             failed("Couldn't create test environment");
         } catch (com.sun.star.lang.IllegalArgumentException e) {
-            log.println("Exception occured while filling calc document with content.");
+            log.println("Exception occurred while filling calc document with content.");
             failed("Couldn't create test environment");
         } catch (com.sun.star.uno.Exception e) {
-            log.println("Exception occured while filling calc document with content.");
+            log.println("Exception occurred while filling calc document with content.");
             failed("Couldn't create test environment");
         }
     }

Modified: openoffice/trunk/main/framework/qa/complex/imageManager/_XInitialization.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/imageManager/_XInitialization.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/imageManager/_XInitialization.java (original)
+++ openoffice/trunk/main/framework/qa/complex/imageManager/_XInitialization.java Tue Apr 29 19:05:05 2014
@@ -71,7 +71,7 @@ public class _XInitialization {
             }
 
         } catch (com.sun.star.uno.Exception e) {
-            System.out.println("Exception occured while method calling.") ;
+            System.out.println("Exception occurred while method calling.") ;
             result = false ;
         }
 

Modified: openoffice/trunk/main/framework/qa/complex/imageManager/_XTypeProvider.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/imageManager/_XTypeProvider.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/imageManager/_XTypeProvider.java (original)
+++ openoffice/trunk/main/framework/qa/complex/imageManager/_XTypeProvider.java Tue Apr 29 19:05:05 2014
@@ -54,7 +54,7 @@ public class _XTypeProvider {
 
     /**
     * Just calls the method.<p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public boolean _getImplementationId() {
         boolean result = true;
--- openoffice/trunk/main/framework/inc/services/autorecovery.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/autorecovery.hxx Tue Apr 29 19:05:05 2014
@@ -117,7 +117,7 @@ struct DispatchParams
 
             @descr  If our dispatch() method was forced to start the
                     internal operation asynchronous ... we send an event
-                    to start and return immediatly. But we must be shure that
+                    to start and return immediately. But we must be sure that
                     our instance live if the event callback reach us.
                     So we hold an uno reference to ourself.
          */
@@ -136,7 +136,7 @@ class AutoRecovery  : public  css::lang:
                     , public  css::document::XEventListener         // => css.lang.XEventListener
                     , public  css::util::XChangesListener           // => css.lang.XEventListener
                     , public  css::util::XModifyListener            // => css.lang.XEventListener
-                    // attention! Must be the first base class to guarentee right initialize lock ...
+                    // attention! Must be the first base class to guarantee right initialize lock ...
                     , private ThreadHelpBase
                     , public  ::cppu::OBroadcastHelper
                     , public  ::cppu::OPropertySetHelper            // => XPropertySet, XFastPropertySet, XMultiPropertySet
@@ -174,9 +174,9 @@ class AutoRecovery  : public  css::lang:
             
             /* FINAL STATES */
 
             /// the Auto/Emergency saved document isnt useable any longer
             E_DAMAGED = 64,
             /// the Auto/Emergency saved document isnt realy up-to-date (some changes can be missing)
             E_INCOMPLETE = 128,
             /// the Auto/Emergency saved document was processed successfully
             E_SUCCEDED = 512
@@ -198,7 +198,7 @@ class AutoRecovery  : public  css::lang:
         // TODO document me
         enum ETimerType
         {
-            /** the timer shouldnt be used next time */
+            /** the timer shouldn't be used next time */
             E_DONT_START_TIMER,
             /** timer (was/must be) started with normal AutoSaveTimeIntervall */
             E_NORMAL_AUTOSAVE_INTERVALL,
@@ -208,7 +208,7 @@ class AutoRecovery  : public  css::lang:
             /** timer mst be started with a very(!) short time intervall,
                 to poll for the end of an user action, which does not allow saving documents in general */
             E_POLL_TILL_AUTOSAVE_IS_ALLOWED,
             /** dont start the timer - but calls the same action then before immediatly again! */
             E_CALL_ME_BACK
         };
 
@@ -250,7 +250,7 @@ class AutoRecovery  : public  css::lang:
                 css::uno::Reference< css::frame::XModel > Document;
 
                 //-------------------------------
-                /** @short  knows, if the document is realy modified since the last autosave,
+                /** @short  knows, if the document is really modified since the last autosave,
                             or  was postponed, because it was an active one etcpp...
 
                     @descr  Because we have no CHANGE TRACKING mechanism, based on office document,
@@ -264,7 +264,7 @@ class AutoRecovery  : public  css::lang:
 
                 //-------------------------------
                 /** Because our applications not ready for concurrent save requests at the same time,
-                    we have supress our own AutoSave for the moment, a document will be already saved
+                    we have suppress our own AutoSave for the moment, a document will be already saved
                     by others.
                  */
                 sal_Bool UsedForSaving;
@@ -298,7 +298,7 @@ class AutoRecovery  : public  css::lang:
                 ::rtl::OUString AppModule;      // e.g. com.sun.star.text.TextDocument - used to identify app module
                 ::rtl::OUString FactoryService; // the service to create a document of the module
                 ::rtl::OUString RealFilter;     // real filter, which was used at loading time
-                ::rtl::OUString DefaultFilter;  // supports saving of the default format without loosing data
+                ::rtl::OUString DefaultFilter;  // supports saving of the default format without losing data
                 ::rtl::OUString Extension;      // file extension of the default filter
                 ::rtl::OUString Title;          // can be used as "DisplayName" on every recovery UI!
                 ::com::sun::star::uno::Sequence< ::rtl::OUString >
@@ -398,9 +398,9 @@ class AutoRecovery  : public  css::lang:
         ListenerHash m_lListener;
 
         /** @descr  This member is used to prevent us against re-entrance problems.
-                    A mutex cant help to prevent us from concurrent using of members
+                    A mutex can't help to prevent us from concurrent using of members
                     inside the same thread. But e.g. our internaly used stl structures
-                    are not threadsafe ... and furthermore they cant be used at the same time
+                    are not threadsafe ... and furthermore they can't be used at the same time
                     for iteration and add/remove requests!
                     So we have to detect such states and ... show a warning.
                     May be there will be a better solution next time ... (copying the cache temp.
@@ -561,7 +561,7 @@ class AutoRecovery  : public  css::lang:
 
             @descr  ... but only keys related to the AutoSave mechanism.
                     Means: State and Timer intervall.
-                    E.g. the recovery list isnt adressed here.
+                    E.g. the recovery list isn't addressed here.
 
             @throw  [com.sun.star.uno.RuntimeException]
                     if config could not be opened or readed successfully!
@@ -705,7 +705,7 @@ class AutoRecovery  : public  css::lang:
         /** @short  save all current opened documents to a specific
                     backup directory.
 
-            @descr  Only realy changed documents will be saved here.
+            @descr  Only really changed documents will be saved here.
 
                     Further this method returns a suggestion, if and how it should
                     be called again. May be some documents was not saved yet
@@ -905,7 +905,7 @@ class AutoRecovery  : public  css::lang:
             
             E.g. our svtools::ConfigItems() has to be flushed explicitly .-(
             
-            Note: This method cant fail. Flushing of config entries is an
+            Note: This method can't fail. Flushing of config entries is an
                   optional feature. Errors can be ignored.
          */
         void impl_flushALLConfigChanges();
@@ -961,14 +961,14 @@ class AutoRecovery  : public  css::lang:
                     a) An external progress is provided by our CrashSave or Recovery dialog.
                     b) We must create our own progress e.g. for an AutoSave
                     c) Sometimes our application filters dont use the progress
-                       provided by the MediaDescriptor. They uses the Frame everytime to create
+                       provided by the MediaDescriptor. They uses the Frame every time to create
                        it's own progress. So we implemented a HACK for these and now we set
                        an InterceptedProgress there for the time WE use this frame for loading/storing documents .-)
 
             @param  xNewFrame
                     must be set only in case WE create a new frame (e.g. for loading documents
                     on session restore or recovery). Then search for a frame using rInfo.Document must
-                    be supressed and xFrame must be preferred instead .-)
+                    be suppressed and xFrame must be preferred instead .-)
 
             @param  rInfo
                     used e.g. to find the frame corresponding to a document.
@@ -989,14 +989,14 @@ class AutoRecovery  : public  css::lang:
         /** try to remove the specified file from disc.
         
             Every URL supported by our UCB component can be used here.
-            Further it doesnt matter if the file realy exists or not.
+            Further it doesn't matter if the file really exists or not.
             Because removing a non exsistent file will have the same
             result at the end ... a non existing file .-)
 
             On the other side removing of files from disc is an optional
             feature. If we are not able doing so ... its not a real problem.
             Ok - users disc place will be samller then ... but we should produce
-            a crash during crash save because we cant delete a temporary file only !
+            a crash during crash save because we can't delete a temporary file only !
             
             @param  sURL
                     the url of the file, which should be removed.
@@ -1005,10 +1005,10 @@ class AutoRecovery  : public  css::lang:
         
         //---------------------------------------
         /** try to remove ".lock" file from disc if office will be terminated
-            not using the offical way .-)
+            not using the official way .-)
             
             This method has to be handled "optional". So every error inside
-            has to be ignored ! This method CANT FAIL ... it can forget something only .-)
+            has to be ignored ! This method CAN'T FAIL ... it can forget something only .-)
          */
         static void st_impl_removeLockFile();
 };
@@ -174,9 +174,9 @@ class AutoRecovery  : public  css::lang:
             /* FINAL STATES */
 
-            /// the Auto/Emergency saved document isnt useable any longer
+            /// the Auto/Emergency saved document isn't useable any longer
             E_DAMAGED = 64,
@@ -174,9 +174,9 @@ class AutoRecovery  : public  css::lang:
             E_DAMAGED = 64,
-            /// the Auto/Emergency saved document isnt realy up-to-date (some changes can be missing)
+            /// the Auto/Emergency saved document isn't really up-to-date (some changes can be missing)
             E_INCOMPLETE = 128,
             /// the Auto/Emergency saved document was processed successfully
@@ -208,7 +208,7 @@ class AutoRecovery  : public  css::lang:
                 to poll for the end of an user action, which does not allow saving documents in general */
             E_POLL_TILL_AUTOSAVE_IS_ALLOWED,
-            /** dont start the timer - but calls the same action then before immediatly again! */
+            /** dont start the timer - but calls the same action then before immediately again! */
             E_CALL_ME_BACK
         };

Modified: openoffice/trunk/main/framework/inc/services/backingcomp.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/backingcomp.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/detectorfactory.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/detectorfactory.hxx Tue Apr 29 19:05:05 2014
@@ -93,7 +93,7 @@ class DetectorFactory : // interfaces
 						public	css::container::XNameContainer		,		// => XNameReplace => XNameAccess => XElementAccess
 						public	css::util::XFlushable				,
 						// base classes
 						// Order is neccessary for right initialization of it!
                         private ThreadHelpBase                      ,
 						public	::cppu::OWeakObject
 {
@@ -361,7 +361,7 @@ class DetectorFactory : // interfaces
         /** @short  check if searched entry exist inside this container.
 
             @attention  In multithreaded environments it's not guaranteed, that a
-                        queried item exist next time realy! It can be deleted by
+                        queried item exist next time really! It can be deleted by
                         another thread ...
 
             @param  sName
@@ -378,7 +378,7 @@ class DetectorFactory : // interfaces
 
         /** @short  return the uno type, which is used for all container items.
 
-            @return Type of sequence< com::sun::star::beans::PropertyValue > everytime - because it's fix.
+            @return Type of sequence< com::sun::star::beans::PropertyValue > every time - because it's fix.
          */
 
         virtual css::uno::Type SAL_CALL getElementType()
@@ -406,8 +406,8 @@ class DetectorFactory : // interfaces
                     Calling of flush() will do that.
                     At the same time all currently registered flush listener will be informed,
                     so they can update her structures too.
-                    Note: Before all these operations are started realy, all changes will be
-                    verified and if neccessary some corrections will be done.
+                    Note: Before all these operations are started really, all changes will be
+                    verified and if necessary some corrections will be done.
                     In case the cache will be invalid and could not be repaired an exception is thrown!
                     Normaly this container will not work correctly afterwards ...
 
@@ -93,7 +93,7 @@ class DetectorFactory : // interfaces
 						public	css::util::XFlushable				,
 						// base classes
-						// Order is neccessary for right initialization of it!
+						// Order is necessary for right initialization of it!
                         private ThreadHelpBase                      ,
 						public	::cppu::OWeakObject

Modified: openoffice/trunk/main/framework/inc/services/frame.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/frame.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/logindialog.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/logindialog.hxx Tue Apr 29 19:05:05 2014
@@ -372,7 +372,7 @@ class cIMPL_Dialog	:	public ModalDialog
 			@descr		This dialog need his own ressource. We can't use the global ressource manager!
 						We must use our own.
 						You must give us the ressource language. If no right ressource could be found -
-						any  existing one is used automaticly!
+						any  existing one is used automatically!
 
 			@seealso	method setValues()
 
@@ -445,7 +445,7 @@ class LoginDialog	:	public XTYPEPROVIDER
 						public XSERVICEINFO					,
 						public XDIALOG						,
                         public XFLUSHABLE                   ,
-                        private ThreadHelpBase              ,   // Order of baseclasses is neccessary for right initialization!
+                        private ThreadHelpBase              ,   // Order of baseclasses is necessary for right initialization!
 						public OBROADCASTHELPER				,
 						public OPROPERTYSETHELPER			,
 						public OWEAKOBJECT
@@ -502,7 +502,7 @@ class LoginDialog	:	public XTYPEPROVIDER
 
         /*-****************************************************************************************************//**
 			@short		write changed values to configuration
-			@descr		Normaly the dialog returns with an OK or ERROR value. If OK occure - we flush data
+			@descr		Normaly the dialog returns with an OK or ERROR value. If OK occur - we flush data
 						auomaticly. But otherwise we do nothing. If user of this service wish to use property set
 						only without any UI(!) - he must call "flush()" explicitly to write data!
 
@@ -597,7 +597,7 @@ class LoginDialog	:	public XTYPEPROVIDER
 						Don't use this directly!
 						You must try to convert the value of given propertyhandle and
 						return results of this operation. This will be use to ask vetoable
-						listener. If no listener have a veto, we will change value realy!
+						listener. If no listener have a veto, we will change value really!
 						( in method setFastPropertyValue_NoBroadcast(...) )
 
 			@seealso	class OPropertySetHelper
@@ -623,7 +623,7 @@ class LoginDialog	:	public XTYPEPROVIDER
 			@descr		This method is calling from helperclass "OPropertySetHelper".
 						Don't use this directly!
 						Handle and value are valid everyway! You must set the new value only.
-						After this, baseclass send messages to all listener automaticly.
+						After this, baseclass send messages to all listener automatically.
 
 			@seealso	OPropertySetHelper
 
@@ -708,7 +708,7 @@ class LoginDialog	:	public XTYPEPROVIDER
 
 		/*-****************************************************************************************************//**
 			@short		helper method to check if a property will change his value
-			@descr		Is neccessary for vetoable listener mechanism of OPropertySethelper.
+			@descr		Is necessary for vetoable listener mechanism of OPropertySethelper.
 
 			@seealso	-
 
@@ -803,9 +803,9 @@ class LoginDialog	:	public XTYPEPROVIDER
 
 		/*-****************************************************************************************************//**
 			@short		helper methods to read/write  properties from/to ini file
-			@descr		Using of Config-Class isn't easy everytime :-(
-						Thats the reason for these helper. State of operation isn't realy important ..
-						but we assert impossible cases or occured errors!
+			@descr		Using of Config-Class isn't easy every time :-(
+						Thats the reason for these helper. State of operation isn't really important ..
+						but we assert impossible cases or occurred errors!
 
 			@seealso	-
 

Modified: openoffice/trunk/main/framework/inc/services/modulemanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/modulemanager.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/pathsettings.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/pathsettings.hxx Tue Apr 29 19:05:05 2014
@@ -67,7 +67,7 @@ class PathSettings : public  css::lang::
                      public  css::lang::XServiceInfo              ,
                      public  css::util::XChangesListener          , // => XEventListener
                      // base classes
                      // Order is neccessary for right initialization!
                      private ThreadHelpBase                       ,
                      public  ::cppu::OBroadcastHelper             ,
                      public  ::cppu::OPropertySetHelper           , // => XPropertySet / XFastPropertySet / XMultiPropertySet
@@ -113,7 +113,7 @@ class PathSettings : public  css::lang::
             /// this special path is used to generate feature depending content there
             ::rtl::OUString sWritePath;
 
-            /// indicates real single pathes, which uses WritePath property only
+            /// indicates real single paths, which uses WritePath property only
             sal_Bool bIsSinglePath;
         
             /// simple handling of finalized/mandatory states ... => we know one state READONLY only .-)
@@ -164,7 +164,7 @@ class PathSettings : public  css::lang::
     public:
 
         /** initialize a new instance of this class.
-            Attention: It's neccessary for right function of this class, that the order of base
+            Attention: It's necessary for right function of this class, that the order of base
             classes is the right one. Because we transfer information from one base to another
             during this ctor runs! */
         PathSettings(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR);
@@ -227,7 +227,7 @@ class PathSettings : public  css::lang::
                         sal_Bool                bReSubst);
 
 
-        /** converts our new string list schema to the old ";" seperated schema ... */
+        /** converts our new string list schema to the old ";" separated schema ... */
         ::rtl::OUString impl_convertPath2OldStyle(const PathSettings::PathInfo& rPath        ) const;
         OUStringList    impl_convertOldStyle2Path(const ::rtl::OUString&        sOldStylePath) const;
 
@@ -67,7 +67,7 @@ class PathSettings : public  css::lang::
                      public  css::util::XChangesListener          , // => XEventListener
                      // base classes
-                     // Order is neccessary for right initialization!
+                     // Order is necessary for right initialization!
                      private ThreadHelpBase                       ,
                      public  ::cppu::OBroadcastHelper             ,

Modified: openoffice/trunk/main/framework/inc/services/pluginframe.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/pluginframe.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/services/pluginframe.hxx (original)
+++ openoffice/trunk/main/framework/inc/services/pluginframe.hxx Tue Apr 29 19:05:05 2014
@@ -80,7 +80,7 @@ namespace framework{
 class PlugInFrame   :   public css::lang::XInitialization           ,
                         public css::mozilla::XPluginInstance        ,
                         public css::frame::XDispatchResultListener  ,   // => XEVENTLISTENER
-                        public Frame                                    // Order of baseclasses is neccessary for right initialization!
+                        public Frame                                    // Order of baseclasses is necessary for right initialization!
 {
 	//-------------------------------------------------------------------------------------------------------------
 	//	public methods
@@ -268,7 +268,7 @@ class PlugInFrame   :   public css::lang
 		sal_Bool															m_bILoad				;	/// PlugInFrame has a valid loader which load the document and wait for finished/cancelled
 		sal_Bool															m_bIHaveDocument		;	/// We have a document loaded successful.
 		css::uno::Reference< css::frame::XDispatchProvider >				m_xPlugInDispatcher		;	/// Dispatcher to forward dispatches to browser
-        static sal_Bool                                                     m_bRemoteFactoriesExist ;   /// indicates, if remote factories was already registered (neccessary one times only!)
+        static sal_Bool                                                     m_bRemoteFactoriesExist ;   /// indicates, if remote factories was already registered (necessary one times only!)
 		SvtCommandOptions													m_aCommandOptions		;	/// ref counted class to support disabling commands defined by configuration file
 
 };		//	class PlugInFrame

Modified: openoffice/trunk/main/framework/inc/services/substitutepathvars.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/services/substitutepathvars.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/threadhelp/writeguard.hxx (original)
+++ openoffice/trunk/main/framework/inc/threadhelp/writeguard.hxx Tue Apr 29 19:05:05 2014
@@ -61,7 +61,7 @@ namespace framework{
 	@short          implement a guard to set write locks
 	@descr			This guard should be used to set a lock for reading AND writing object internal member.
 					We never need a own mutex to safe our internal member access - because
-					a guard is used as function-local member only. There exist no multithreaded access to it realy ...
+					a guard is used as function-local member only. There exist no multithreaded access to it really ...
 
     @attention      a) To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
                     b) Use interface "IRWLock" of set LockHelper only - because we must support a finer granularity of locking.
@@ -109,7 +109,7 @@ class WriteGuard : private INonCopyable
 
         /*-****************************************************************************************************//**
             @short      dtor
-            @descr      We unlock the used lock member automaticly if user forget it.
+            @descr      We unlock the used lock member automatically if user forget it.
 
             @seealso    -
 
@@ -160,7 +160,7 @@ class WriteGuard : private INonCopyable
         /*-****************************************************************************************************//**
             @short      unset write lock
             @descr      Call this method to unlock the rw-lock temp.!
-                        Normaly we do it at dtor automaticly for you ...
+                        Normaly we do it at dtor automatically for you ...
 
             @seealso    method lock()
 
@@ -175,7 +175,7 @@ class WriteGuard : private INonCopyable
             {
                 case E_READLOCK     :   {
                                             // User has downgraded to a read lock before!
                                             // => There isn't realy a write lock ...
                                             m_pLock->releaseReadAccess();
                                             m_eMode = E_NOLOCK;
                                         }
@@ -219,7 +219,7 @@ class WriteGuard : private INonCopyable
             @param      -
             @return     Current set lock mode.
 
-            @onerror    No error should occure.
+            @onerror    No error should occur.
         *//*-*****************************************************************************************************/
         inline ELockMode getMode() const
         {
@@ -233,7 +233,7 @@ class WriteGuard : private INonCopyable
 
 		/*-****************************************************************************************************//**
 			@short		disable using of these functions!
-			@descr		It's not allowed to use this methods. Different problem can occure otherwise.
+			@descr		It's not allowed to use this methods. Different problem can occur otherwise.
 						Thats why we disable it by make it private.
 
 			@seealso	other ctor
@@ -175,7 +175,7 @@ class WriteGuard : private INonCopyable
                 case E_READLOCK     :   {
                                             // User has downgraded to a read lock before!
-                                            // => There isn't realy a write lock ...
+                                            // => There isn't really a write lock ...
                                             m_pLock->releaseReadAccess();
                                             m_eMode = E_NOLOCK;

Modified: openoffice/trunk/main/framework/inc/uifactory/uielementfactorymanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/uifactory/uielementfactorymanager.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================